@@ -23,15 +23,12 @@ import os
 import sys
 import tempfile
 import logging
-import gobject
 from whipper.command.basecommand import BaseCommand
 from whipper.common import accurip, common, config, drive
 from whipper.common import task as ctask
 from whipper.program import arc, cdrdao, cdparanoia, utils
 from whipper.extern.task import task
 
-gobject.threads_init()
-
 logger = logging.getLogger(__name__)
 
 # see http://www.accuraterip.com/driveoffsets.htm
@@ -70,7 +67,7 @@ CD in the AccurateRip database."""
         for b in blocks:
             if ':' in b:
                 a, b = b.split(':')
-                self._offsets.extend(range(int(a), int(b) + 1))
+                self._offsets.extend(list(range(int(a), int(b) + 1)))
             else:
                 self._offsets.append(int(b))
 
@@ -120,7 +117,7 @@ CD in the AccurateRip database."""
             sys.stdout.write('Trying read offset %d ...\n' % offset)
             try:
                 archecksums = self._arcs(runner, table, 1, offset)
-            except task.TaskException, e:
+            except task.TaskException as e:
 
                 # let MissingDependency fall through
                 if isinstance(e.exception,
@@ -153,7 +150,7 @@ CD in the AccurateRip database."""
                 for track in range(2, (len(table.tracks) + 1) - 1):
                     try:
                         archecksums = self._arcs(runner, table, track, offset)
-                    except task.TaskException, e:
+                    except task.TaskException as e:
                         if isinstance(e.exception, cdparanoia.FileSizeError):
                             sys.stdout.write(
                                 'WARNING: cannot rip with offset %d...\n' %
