@@ -31,6 +31,7 @@ import time
 from whipper.common import accurip, cache, checksum, common, mbngs, path
 from whipper.program import cdrdao, cdparanoia
 from whipper.image import image
+from whipper.extern import freedb
 from whipper.extern.task import task
 
 import logging
@@ -71,10 +72,10 @@ class Program:
 
         d = {}
 
-        for key, default in {
+        for key, default in list({
             'fat': True,
             'special': False
-        }.items():
+        }.items()):
             value = None
             value = self._config.getboolean('main', 'path_filter_' + key)
             if value is None:
@@ -90,23 +91,16 @@ class Program:
             os.chdir(workingDirectory)
 
     def getFastToc(self, runner, device):
-        """Retrieve the normal TOC table from a toc pickle or the drive.
-        Also retrieves the cdrdao version
+        """Retrieve the normal TOC table from the drive.
+        Also warn about buggy cdrdao versions.
         """
-        def function(r, t):
-            r.run(t)
-
-        ptoc = cache.Persister()
-        if not ptoc.object:
-            from pkg_resources import parse_version as V
-            version = cdrdao.getCDRDAOVersion()
-            if V(version) < V('1.2.3rc2'):
-                sys.stdout.write('Warning: cdrdao older than 1.2.3 has a '
-                                 'pre-gap length bug.\n'
-                                 'See http://sourceforge.net/tracker/?func=detail&aid=604751&group_id=2171&atid=102171\n')  # noqa: E501
-            t = cdrdao.ReadTOCTask(device)
-            ptoc.persist(t.table)
-        toc = ptoc.object
+        from pkg_resources import parse_version as V
+        version = cdrdao.getCDRDAOVersion()
+        if V(version) < V('1.2.3rc2'):
+            sys.stdout.write('Warning: cdrdao older than 1.2.3 has a '
+                             'pre-gap length bug.\n'
+                             'See http://sourceforge.net/tracker/?func=detail&aid=604751&group_id=2171&atid=102171\n')  # noqa: E501
+        toc = cdrdao.ReadTOCTask(device).table
         assert toc.hasTOC()
         return toc
 
@@ -122,7 +116,7 @@ class Program:
         tdict = {}
 
         # Ignore old cache, since we do not know what offset it used.
-        if type(ptable.object) is dict:
+        if isinstance(ptable.object, dict):
             tdict = ptable.object
 
             if offset in tdict:
@@ -200,8 +194,8 @@ class Program:
           - %x: audio extension, lowercase
           - %X: audio extension, uppercase
         """
-        assert type(outdir) is unicode, "%r is not unicode" % outdir
-        assert type(template) is unicode, "%r is not unicode" % template
+        assert isinstance(outdir, unicode), "%r is not unicode" % outdir
+        assert isinstance(template, unicode), "%r is not unicode" % template
         v = {}
         v['A'] = 'Unknown Artist'
         v['d'] = mbdiscid  # fallback for title
@@ -252,17 +246,18 @@ class Program:
         @rtype: str
         """
         # FIXME: convert to nonblocking?
-        import CDDB
         try:
-            code, md = CDDB.query(cddbdiscid)
-            logger.debug('CDDB query result: %r, %r', code, md)
-            if code == 200:
-                return md['title']
+            md = freedb.perform_lookup(cddbdiscid, 'freedb.freedb.org', 80)
+            logger.debug('CDDB query result: %r', md)
+            return [item['DTITLE'] for item in md if 'DTITLE' in item] or None
 
-        except IOError, e:
+        except ValueError as e:
+            self._stdout.write("WARNING: CDDB protocol error: %s\n" % e)
+
+        except IOError as e:
             # FIXME: for some reason errno is a str ?
             if e.errno == 'socket error':
-                self._stdout.write("Warning: network error: %r\n" % (e, ))
+                self._stdout.write("WARNING: CDDB network error: %r\n" % (e, ))
             else:
                 raise
 
@@ -290,13 +285,13 @@ class Program:
                                               country=country,
                                               record=self._record)
                 break
-            except mbngs.NotFoundException, e:
+            except mbngs.NotFoundException as e:
                 logger.warning("release not found: %r" % (e, ))
                 break
-            except musicbrainzngs.NetworkError, e:
+            except musicbrainzngs.NetworkError as e:
                 logger.warning("network error: %r" % (e, ))
                 break
-            except mbngs.MusicBrainzException, e:
+            except mbngs.MusicBrainzException as e:
                 logger.warning("musicbrainz exception: %r" % (e, ))
                 time.sleep(5)
                 continue
@@ -336,7 +331,7 @@ class Program:
 
             if not release and len(metadatas) > 1:
                 # Select the release that most closely matches the duration.
-                lowest = min(deltas.keys())
+                lowest = min(list(deltas))
 
                 if prompt:
                     guess = (deltas[lowest])[0].mbid
@@ -382,7 +377,7 @@ class Program:
                                            releaseTitle, i,
                                            metadata.releaseTitle))
 
-                if (not release and len(deltas.keys()) > 1):
+                if (not release and len(list(deltas)) > 1):
                     self._stdout.write('\n')
                     self._stdout.write('Picked closest match in duration.\n')
                     self._stdout.write('Others may be wrong in MusicBrainz, '
@@ -431,8 +426,8 @@ class Program:
                     title = track.title
                     mbidTrack = track.mbid
                     mbidTrackArtist = track.mbidArtist
-                except IndexError, e:
-                    print 'ERROR: no track %d found, %r' % (number, e)
+                except IndexError as e:
+                    print('ERROR: no track %d found, %r' % (number, e))
                     raise
             else:
                 # htoa defaults to disc's artist
@@ -485,7 +480,7 @@ class Program:
 
         try:
             runner.run(t)
-        except task.TaskException, e:
+        except task.TaskException as e:
             if isinstance(e.exception, common.MissingFrames):
                 logger.warning('missing frames for %r' % trackResult.filename)
                 return False
@@ -549,11 +544,6 @@ class Program:
             trackResult.filename = t.path
             logger.info('Filename changed to %r', trackResult.filename)
 
-    def retagImage(self, runner, taglists):
-        cueImage = image.Image(self.cuePath)
-        t = image.ImageRetagTask(cueImage, taglists)
-        runner.run(t)
-
     def verifyImage(self, runner, table):
         """
         verify table against accuraterip and cue_path track lengths
@@ -577,14 +567,14 @@ class Program:
 
         checksums = accurip.calculate_checksums([
             os.path.join(os.path.dirname(self.cuePath), t.indexes[1].path)
-            for t in filter(lambda t: t.number != 0, cueImage.cue.table.tracks)
+            for t in [t for t in cueImage.cue.table.tracks if t.number != 0]
         ])
         if not (checksums and any(checksums['v1']) and any(checksums['v2'])):
             return False
         return accurip.verify_result(self.result, responses, checksums)
 
     def write_m3u(self, discname):
-        m3uPath = u'%s.m3u' % discname
+        m3uPath = common.truncate_filename(discname + '.m3u')
         with open(m3uPath, 'w') as f:
             f.write(u'#EXTM3U\n'.encode('utf-8'))
             for track in self.result.tracks:
@@ -606,7 +596,7 @@ class Program:
 
     def writeCue(self, discName):
         assert self.result.table.canCue()
-        cuePath = '%s.cue' % discName
+        cuePath = common.truncate_filename(discName + '.cue')
         logger.debug('write .cue file to %s', cuePath)
         handle = open(cuePath, 'w')
         # FIXME: do we always want utf-8 ?
@@ -618,7 +608,7 @@ class Program:
         return cuePath
 
     def writeLog(self, discName, logger):
-        logPath = '%s.log' % discName
+        logPath = common.truncate_filename(discName + '.log')
         handle = open(logPath, 'w')
         log = logger.log(self.result)
         handle.write(log.encode('utf-8'))
