@@ -31,7 +31,7 @@ class TestAccurateRipResponse(TestCase):
         accurip._CACHE_DIR = self.cache_dir
 
         def cleanup(cachedir):
-            chmod(cachedir, 0755)
+            chmod(cachedir, 0o755)
             rmtree(cachedir)
         self.addCleanup(cleanup, self.cache_dir)
 
@@ -43,7 +43,7 @@ class TestAccurateRipResponse(TestCase):
             join(self.cache_dir, self.other_path)
         )
         # ask cache for other entry and assert cached entry equals normal entry
-        self.assertEquals(self.entry, get_db_entry(self.other_path))
+        self.assertEqual(self.entry, get_db_entry(self.other_path))
 
     def test_raises_entrynotfound_for_no_entry(self):
         with self.assertRaises(EntryNotFound):
@@ -52,43 +52,43 @@ class TestAccurateRipResponse(TestCase):
     def test_can_return_entry_without_saving(self):
         chmod(self.cache_dir, 0)
         self.assertEqual(get_db_entry(self.path), self.entry)
-        chmod(self.cache_dir, 0755)
+        chmod(self.cache_dir, 0o755)
         self.assertFalse(exists(join(self.cache_dir, self.path)))
 
     def test_retrieves_and_saves_accuraterip_entry(self):
         # for path, entry in zip(self.paths[0], self.entries):
         self.assertFalse(exists(join(self.cache_dir, self.path)))
-        self.assertEquals(get_db_entry(self.path), self.entry)
+        self.assertEqual(get_db_entry(self.path), self.entry)
         self.assertTrue(exists(join(self.cache_dir, self.path)))
 
     def test_AccurateRipResponse_parses_correctly(self):
         responses = get_db_entry(self.path)
-        self.assertEquals(len(responses), 2)
+        self.assertEqual(len(responses), 2)
 
-        self.assertEquals(responses[0].num_tracks, 2)
-        self.assertEquals(responses[0].discId1, '0000f21c')
-        self.assertEquals(responses[0].discId2, '00027ef8')
-        self.assertEquals(responses[0].cddbDiscId, '05021002')
-        self.assertEquals(responses[0].confidences[0], 12)
-        self.assertEquals(responses[0].confidences[1], 20)
-        self.assertEquals(responses[0].checksums[0], '284fc705')
-        self.assertEquals(responses[0].checksums[1], '9cc1f32e')
+        self.assertEqual(responses[0].num_tracks, 2)
+        self.assertEqual(responses[0].discId1, '0000f21c')
+        self.assertEqual(responses[0].discId2, '00027ef8')
+        self.assertEqual(responses[0].cddbDiscId, '05021002')
+        self.assertEqual(responses[0].confidences[0], 12)
+        self.assertEqual(responses[0].confidences[1], 20)
+        self.assertEqual(responses[0].checksums[0], '284fc705')
+        self.assertEqual(responses[0].checksums[1], '9cc1f32e')
 
-        self.assertEquals(responses[1].num_tracks, 2)
-        self.assertEquals(responses[1].discId1, '0000f21c')
-        self.assertEquals(responses[1].discId2, '00027ef8')
-        self.assertEquals(responses[1].cddbDiscId, '05021002')
-        self.assertEquals(responses[1].confidences[0], 4)
-        self.assertEquals(responses[1].confidences[1], 4)
-        self.assertEquals(responses[1].checksums[0], 'dc77f9ab')
-        self.assertEquals(responses[1].checksums[1], 'dd97d2c3')
+        self.assertEqual(responses[1].num_tracks, 2)
+        self.assertEqual(responses[1].discId1, '0000f21c')
+        self.assertEqual(responses[1].discId2, '00027ef8')
+        self.assertEqual(responses[1].cddbDiscId, '05021002')
+        self.assertEqual(responses[1].confidences[0], 4)
+        self.assertEqual(responses[1].confidences[1], 4)
+        self.assertEqual(responses[1].checksums[0], 'dc77f9ab')
+        self.assertEqual(responses[1].checksums[1], 'dd97d2c3')
 
 # XXX: test arc.py
 
 
 class TestCalculateChecksums(TestCase):
     def test_returns_none_for_bad_files(self):
-        self.assertEquals(
+        self.assertEqual(
             calculate_checksums(['/does/not/exist']),
             {'v1': [None], 'v2': [None]}
         )
@@ -116,26 +116,26 @@ class TestVerifyResult(TestCase):
             self.result.tracks.append(track)
 
     def test_empty_result_returns_false(self):
-        self.assertEquals(
+        self.assertEqual(
             verify_result(RipResult(), self.responses, self.checksums),
             False
         )
 
     def test_empty_responses_returns_false(self):
-        self.assertEquals(
+        self.assertEqual(
             verify_result(self.result, [], self.checksums),
             False
         )
 
     # XXX: would this happen?
     def test_empty_checksums_returns_false(self):
-        self.assertEquals(
+        self.assertEqual(
             verify_result(self.result, self.responses, {}),
             False
         )
 
     def test_wrong_checksums_returns_false(self):
-        self.assertEquals(
+        self.assertEqual(
             verify_result(self.result, self.responses, {
                 'v1': ['deadbeef', '89abcdef'],
                 'v2': ['76543210', '01234567']
@@ -144,21 +144,21 @@ class TestVerifyResult(TestCase):
         )
 
     def test_incomplete_checksums(self):
-        self.assertEquals(
+        self.assertEqual(
             verify_result(self.result, self.responses, {
                 'v1': ['284fc705', '9cc1f32e'],
                 'v2': [None, 'dd97d2c3'],
             }),
             True
         )
-        self.assertEquals(
+        self.assertEqual(
             verify_result(self.result, self.responses, {
                 'v1': ['284fc705', None],
                 'v2': ['dc77f9ab', 'dd97d2c3'],
             }),
             True
         )
-        self.assertEquals(
+        self.assertEqual(
             verify_result(self.result, self.responses, {
                 'v1': ['284fc705', None],
                 'v2': [None, 'dd97d2c3'],
@@ -167,13 +167,13 @@ class TestVerifyResult(TestCase):
         )
 
     def test_matches_only_v1_or_v2_responses(self):
-        self.assertEquals(
+        self.assertEqual(
             verify_result(
                 self.result, [self.responses[0]], self.checksums
             ),
             True
         )
-        self.assertEquals(
+        self.assertEqual(
             verify_result(
                 self.result, [self.responses[1]], self.checksums
             ),
@@ -184,17 +184,17 @@ class TestVerifyResult(TestCase):
         htoa = TrackResult()
         htoa.number = 0
         self.result.tracks.append(htoa)
-        self.assertEquals(
+        self.assertEqual(
             verify_result(self.result, self.responses, self.checksums),
             True
         )
 
     def test_stores_accuraterip_results_on_result(self):
-        self.assertEquals(
+        self.assertEqual(
             verify_result(self.result, self.responses, self.checksums),
             True
         )
-        self.assertEquals(self.result.tracks[0].AR, {
+        self.assertEqual(self.result.tracks[0].AR, {
             'v1': {
                 'CRC': '284fc705',
                 'DBCRC': '284fc705',
@@ -208,7 +208,7 @@ class TestVerifyResult(TestCase):
             'DBMaxConfidence': 12,
             'DBMaxConfidenceCRC': '284fc705',
         })
-        self.assertEquals(self.result.tracks[1].AR, {
+        self.assertEqual(self.result.tracks[1].AR, {
             'v1': {
                 'CRC': '9cc1f32e',
                 'DBCRC': '9cc1f32e',
@@ -254,7 +254,7 @@ class TestAccurateRipReport(TestCase):
         track.number = 1
         self.result.tracks[0] = track
         print_report(self.result)
-        self.assertEquals(
+        self.assertEqual(
             sys.stdout.getvalue(),
             'track  1: unknown          (error)\n'
         )
@@ -262,7 +262,7 @@ class TestAccurateRipReport(TestCase):
     def test_track_not_found(self):
         self.result.tracks[0].AR['DBMaxConfidence'] = None
         print_report(self.result)
-        self.assertEquals(
+        self.assertEqual(
             sys.stdout.getvalue(),
             'track  1: rip NOT accurate (not found)            '
             ' v1 [284fc705], v2 [dc77f9ab], DB [notfound]\n'
@@ -273,7 +273,7 @@ class TestAccurateRipReport(TestCase):
         self.result.tracks[0].AR['v1']['CRC'] = None
         self.result.tracks[0].AR['v2']['CRC'] = None
         print_report(self.result)
-        self.assertEquals(
+        self.assertEqual(
             sys.stdout.getvalue(),
             'track  0: unknown          (not tracked)\n'
         )
@@ -282,7 +282,7 @@ class TestAccurateRipReport(TestCase):
         self.result.tracks[0].AR['v2']['DBCRC'] = None
         self.result.tracks[0].AR['v2']['DBConfidence'] = None
         print_report(self.result)
-        self.assertEquals(
+        self.assertEqual(
             sys.stdout.getvalue(),
             'track  1: rip accurate     (max confidence     12)'
             ' v1 [284fc705], v2 [dc77f9ab], DB [284fc705]\n'
@@ -292,7 +292,7 @@ class TestAccurateRipReport(TestCase):
         self.result.tracks[0].AR['v1']['DBCRC'] = None
         self.result.tracks[0].AR['v1']['DBConfidence'] = None
         print_report(self.result)
-        self.assertEquals(
+        self.assertEqual(
             sys.stdout.getvalue(),
             'track  1: rip accurate     (confidence   4 of  12)'
             ' v1 [284fc705], v2 [dc77f9ab], DB [dc77f9ab]\n'
@@ -300,7 +300,7 @@ class TestAccurateRipReport(TestCase):
 
     def test_report_v1_and_v2_max_confidence(self):
         print_report(self.result)
-        self.assertEquals(
+        self.assertEqual(
             sys.stdout.getvalue(),
             'track  1: rip accurate     (max confidence     12)'
             ' v1 [284fc705], v2 [dc77f9ab], DB [284fc705, dc77f9ab]\n'
@@ -309,7 +309,7 @@ class TestAccurateRipReport(TestCase):
     def test_report_v1_and_v2(self):
         self.result.tracks[0].AR['DBMaxConfidence'] = 66
         print_report(self.result)
-        self.assertEquals(
+        self.assertEqual(
             sys.stdout.getvalue(),
             'track  1: rip accurate     (confidence  12 of  66)'
             ' v1 [284fc705], v2 [dc77f9ab], DB [284fc705, dc77f9ab]\n'
